@@ -1,38 +1,18 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libcdr
- * Version: MPL 1.1 / GPLv2+ / LGPLv2+
+/*
+ * This file is part of the libcdr project.
  *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License or as specified alternatively below. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * Major Contributor(s):
- * Copyright (C) 2012 Fridrich Strba <fridrich.strba@bluewin.ch>
- *
- *
- * All Rights Reserved.
- *
- * For minor contributions see the git repository.
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
- * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
- * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
- * instead of those above.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #include <math.h>
 #include <string.h>
+#include <libcdr/libcdr.h>
 #include "CDRSVGGenerator.h"
 #include "CDRContentCollector.h"
 #include "CDRInternalStream.h"
-#include "CMXDocument.h"
 #include "libcdr_utils.h"
 
 #ifndef M_PI
@@ -153,45 +133,15 @@ void libcdr::CDRContentCollector::collectOtherList()
 //  m_isPageProperties = false;
 }
 
-void libcdr::CDRContentCollector::collectCubicBezier(double x1, double y1, double x2, double y2, double x, double y)
+void libcdr::CDRContentCollector::collectPath(const CDRPath &path)
 {
-  CDR_DEBUG_MSG(("CDRContentCollector::collectCubicBezier(%f, %f, %f, %f, %f, %f)\n", x1, y1, x2, y2, x, y));
-  m_currentPath.appendCubicBezierTo(x1, y1, x2, y2, x, y);
-}
-
-void libcdr::CDRContentCollector::collectQuadraticBezier(double x1, double y1, double x, double y)
-{
-  CDR_DEBUG_MSG(("CDRContentCollector::collectQuadraticBezier(%f, %f, %f, %f)\n", x1, y1, x, y));
-  m_currentPath.appendQuadraticBezierTo(x1, y1, x, y);
-}
-
-void libcdr::CDRContentCollector::collectMoveTo(double x, double y)
-{
-  CDR_DEBUG_MSG(("CDRContentCollector::collectMoveTo(%f, %f)\n", x, y));
-  m_currentPath.appendMoveTo(x,y);
-}
-
-void libcdr::CDRContentCollector::collectLineTo(double x, double y)
-{
-  CDR_DEBUG_MSG(("CDRContentCollector::collectLineTo(%f, %f)\n", x, y));
-  m_currentPath.appendLineTo(x, y);
-}
-
-void libcdr::CDRContentCollector::collectArcTo(double rx, double ry, bool largeArc, bool sweep, double x, double y)
-{
-  CDR_DEBUG_MSG(("CDRContentCollector::collectArcTo(%f, %f)\n", x, y));
-  m_currentPath.appendArcTo(rx, ry, 0.0, largeArc, sweep, x, y);
-}
-
-void libcdr::CDRContentCollector::collectClosePath()
-{
-  CDR_DEBUG_MSG(("CDRContentCollector::collectClosePath\n"));
-  m_currentPath.appendClosePath();
+  CDR_DEBUG_MSG(("CDRContentCollector::collectPath\n"));
+  m_currentPath.appendPath(path);
 }
 
 void libcdr::CDRContentCollector::_flushCurrentPath()
 {
-  CDR_DEBUG_MSG(("CDRContentCollector::collectFlushPath\n"));
+  CDR_DEBUG_MSG(("CDRContentCollector::_flushCurrentPath\n"));
   CDROutputElementList outputElement;
   if (!m_currentPath.empty() || (!m_splineData.empty() && m_isInSpline))
   {
@@ -271,9 +221,7 @@ void libcdr::CDRContentCollector::_flushCurrentPath()
                 }
               }
               else
-              {
                 tmpPath.pop_back();
-              }
             }
           }
 
@@ -296,6 +244,11 @@ void libcdr::CDRContentCollector::_flushCurrentPath()
         }
 
       }
+      else if (i()["libwpg:path-action"]->getStr() == "Z")
+      {
+        if (tmpPath.back()["libwpg:path-action"] && tmpPath.back()["libwpg:path-action"]->getStr() != "Z")
+          tmpPath.push_back(i());
+      }
     }
     if (!tmpPath.empty())
     {
@@ -303,9 +256,12 @@ void libcdr::CDRContentCollector::_flushCurrentPath()
       {
         if ((CDR_ALMOST_ZERO(initialX - previousX) && CDR_ALMOST_ZERO(initialY - previousY)) || isPathClosed)
         {
-          WPXPropertyList closedPath;
-          closedPath.insert("libwpg:path-action", "Z");
-          tmpPath.push_back(closedPath);
+          if (tmpPath.back()["libwpg:path-action"] && tmpPath.back()["libwpg:path-action"]->getStr() != "Z")
+          {
+            WPXPropertyList closedPath;
+            closedPath.insert("libwpg:path-action", "Z");
+            tmpPath.push_back(closedPath);
+          }
         }
       }
       else
@@ -599,9 +555,9 @@ void libcdr::CDRContentCollector::collectFillStyle(unsigned short fillType, cons
 
 void libcdr::CDRContentCollector::collectLineStyle(unsigned short lineType, unsigned short capsType, unsigned short joinType, double lineWidth,
     double stretch, double angle, const CDRColor &color, const std::vector<unsigned> &dashArray,
-    unsigned startMarkerId, unsigned endMarkerId)
+    const CDRPath &startMarker, const CDRPath &endMarker)
 {
-  m_currentLineStyle = CDRLineStyle(lineType, capsType, joinType, lineWidth, stretch, angle, color, dashArray, startMarkerId, endMarkerId);
+  m_currentLineStyle = CDRLineStyle(lineType, capsType, joinType, lineWidth, stretch, angle, color, dashArray, startMarker, endMarker);
 }
 
 void libcdr::CDRContentCollector::collectRotate(double angle, double cx, double cy)
@@ -661,7 +617,7 @@ void libcdr::CDRContentCollector::_fillProperties(WPXPropertyList &propList, WPX
         }
         else if (m_currentFillStyle.gradient.m_stops.size() == 2)
         {
-          double angle = m_currentFillStyle.gradient.m_angle;
+          double angle = m_currentFillStyle.gradient.m_angle * 180 / M_PI;
           while (angle < 0.0)
             angle += 360.0;
           while (angle > 360.0)
@@ -719,7 +675,7 @@ void libcdr::CDRContentCollector::_fillProperties(WPXPropertyList &propList, WPX
         {
           propList.insert("draw:fill", "gradient");
           propList.insert("draw:style", "linear");
-          double angle = m_currentFillStyle.gradient.m_angle;
+          double angle = m_currentFillStyle.gradient.m_angle * 180 / M_PI;
           angle += 90.0;
           while (angle < 0.0)
             angle += 360.0;
@@ -1056,8 +1012,42 @@ void libcdr::CDRContentCollector::_lineProperties(WPXPropertyList &propList)
       propList.insert("svg:stroke-width", 0.0);
       propList.insert("svg:stroke-color", "#000000");
     }
-
   }
+
+  // Deal with line markers (arrows, etc.)
+  if (!m_currentLineStyle.startMarker.empty())
+  {
+    CDRPath startMarker(m_currentLineStyle.startMarker);
+    startMarker.transform(m_currentTransforms);
+    if (!m_groupTransforms.empty())
+      startMarker.transform(m_groupTransforms.top());
+    CDRTransform tmpTrafo = CDRTransform(1.0, 0.0, 0.0, 0.0, -1.0, 0);
+    startMarker.transform(tmpTrafo);
+    WPXString path, viewBox;
+    double width;
+    startMarker.writeOut(path, viewBox, width);
+    propList.insert("draw:marker-start-viewbox", viewBox);
+    propList.insert("draw:marker-start-path", path);
+    // propList.insert("draw:marker-start-width", width);
+  }
+  if (!m_currentLineStyle.endMarker.empty())
+  {
+    CDRPath endMarker(m_currentLineStyle.endMarker);
+    endMarker.transform(m_currentTransforms);
+    if (!m_groupTransforms.empty())
+      endMarker.transform(m_groupTransforms.top());
+    CDRTransform tmpTrafo = CDRTransform(-1.0, 0.0, 0.0, 0.0, -1.0, 0);
+    endMarker.transform(tmpTrafo);
+    WPXString path, viewBox;
+    double width;
+    endMarker.writeOut(path, viewBox, width);
+    propList.insert("draw:marker-end-viewbox", viewBox);
+    propList.insert("draw:marker-end-path", path);
+    // propList.insert("draw:marker-end-width", width);
+  }
+
+
+
 }
 
 void libcdr::CDRContentCollector::_generateBitmapFromPattern(WPXBinaryData &bitmap, const CDRPattern &pattern, const CDRColor &fgColor, const CDRColor &bgColor)
