@@ -1,30 +1,10 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libcdr
- * Version: MPL 1.1 / GPLv2+ / LGPLv2+
+/*
+ * This file is part of the libcdr project.
  *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License or as specified alternatively below. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * Major Contributor(s):
- * Copyright (C) 2012 Fridrich Strba <fridrich.strba@bluewin.ch>
- *
- *
- * All Rights Reserved.
- *
- * For minor contributions see the git repository.
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
- * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
- * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
- * instead of those above.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #ifndef __CDRCONTENTCOLLECTOR_H__
@@ -55,26 +35,20 @@ public:
   void collectGroup(unsigned level);
   void collectVect(unsigned level);
   void collectOtherList();
-  void collectCubicBezier(double x1, double y1, double x2, double y2, double x, double y);
-  void collectQuadraticBezier(double x1, double y1, double x, double y);
-  void collectMoveTo(double x, double y);
-  void collectLineTo(double x, double y);
-  void collectArcTo(double rx, double ry, bool largeArc, bool sweep, double x, double y);
-  void collectClosePath();
+  void collectPath(const CDRPath &path);
   void collectLevel(unsigned level);
   void collectTransform(const CDRTransforms &transforms, bool considerGroupTransform);
-  void collectFildId(unsigned id);
-  void collectOutlId(unsigned id);
-  void collectFild(unsigned, unsigned short, const CDRColor &, const CDRColor &, const CDRGradient &, const CDRImageFill &) {}
-  void collectOutl(unsigned, unsigned short, unsigned short, unsigned short, double, double, double, const CDRColor &,
-                   const std::vector<unsigned> &, unsigned, unsigned) {}
+  void collectFillStyle(unsigned short fillType, const CDRColor &color1, const CDRColor &color2, const CDRGradient &gradient, const CDRImageFill &imageFill);
+  void collectLineStyle(unsigned short lineType, unsigned short capsType, unsigned short joinType, double lineWidth,
+                        double stretch, double angle, const CDRColor &color, const std::vector<unsigned> &dashArray,
+                        const CDRPath &startMarker, const CDRPath &endMarker);
   void collectRotate(double angle, double cx, double cy);
   void collectFlags(unsigned flags, bool considerFlags);
   void collectPageSize(double, double, double, double) {}
   void collectPolygonTransform(unsigned numAngles, unsigned nextPoint, double rx, double ry, double cx, double cy);
   void collectBitmap(unsigned imageId, double x1, double x2, double y1, double y2);
-  void collectBmp(unsigned, unsigned, unsigned, unsigned, unsigned, const std::vector<unsigned>&, const std::vector<unsigned char>&) {}
-  void collectBmp(unsigned, const std::vector<unsigned char>&) {}
+  void collectBmp(unsigned, unsigned, unsigned, unsigned, unsigned, const std::vector<unsigned> &, const std::vector<unsigned char> &) {}
+  void collectBmp(unsigned, const std::vector<unsigned char> &) {}
   void collectBmpf(unsigned, unsigned, unsigned, const std::vector<unsigned char> &) {}
   void collectPpdt(const std::vector<std::pair<double, double> > &points, const std::vector<unsigned> &knotVector);
   void collectFillTransform(const CDRTransforms &fillTrafo);
@@ -86,12 +60,11 @@ public:
   void collectSpnd(unsigned spnd);
   void collectVectorPattern(unsigned id, const WPXBinaryData &data);
   void collectPaletteEntry(unsigned, unsigned, const CDRColor &) {}
-  void collectFont(unsigned, unsigned short, const WPXString &) {}
-  void collectText(unsigned, unsigned, const std::vector<unsigned char>&,
-                   const std::vector<uint64_t>&, const std::map<unsigned, CDRCharacterStyle>&) {}
-  void collectArtisticText();
-  void collectParagraphText();
-  void collectStlt(const std::map<unsigned, CDRCharacterStyle> &) {}
+  void collectText(unsigned, unsigned, const std::vector<unsigned char> &,
+                   const std::vector<unsigned char> &, const std::map<unsigned, CDRCharacterStyle> &) {}
+  void collectArtisticText(double x, double y);
+  void collectParagraphText(double x, double y, double width, double height);
+  void collectStld(unsigned, const CDRCharacterStyle &) {}
 
 private:
   CDRContentCollector(const CDRContentCollector &);
@@ -114,14 +87,14 @@ private:
 
   CDRPage m_page;
   unsigned m_pageIndex;
-  unsigned m_currentFildId, m_currentOutlId;
+  CDRFillStyle m_currentFillStyle;
+  CDRLineStyle m_currentLineStyle;
   unsigned m_spnd;
   unsigned m_currentObjectLevel, m_currentGroupLevel, m_currentVectLevel, m_currentPageLevel;
   CDRImage m_currentImage;
-  const std::vector<CDRText> *m_currentText;
-  double m_currentTextOffsetX;
-  double m_currentTextOffsetY;
-  CDRBBox m_currentBBox;
+  const std::vector<CDRTextLine> *m_currentText;
+  CDRBox m_currentBBox;
+  CDRBox m_currentTextBox;
 
   CDRPath m_currentPath;
   CDRTransforms m_currentTransforms;
