@@ -1,30 +1,10 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libcdr
- * Version: MPL 1.1 / GPLv2+ / LGPLv2+
+/*
+ * This file is part of the libcdr project.
  *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License or as specified alternatively below. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * Major Contributor(s):
- * Copyright (C) 2012 Fridrich Strba <fridrich.strba@bluewin.ch>
- *
- *
- * All Rights Reserved.
- *
- * For minor contributions see the git repository.
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
- * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
- * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
- * instead of those above.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #ifndef __CDRPATH_H__
@@ -33,12 +13,11 @@
 #include <vector>
 #include <libwpd/libwpd.h>
 
-#include "CDRTypes.h"
-
 namespace libcdr
 {
 
 class CDRTransform;
+class CDRTransforms;
 
 class CDRPathElement
 {
@@ -59,6 +38,8 @@ public:
   CDRPath(const CDRPath &path);
   ~CDRPath();
 
+  CDRPath &operator=(const CDRPath &path);
+
   void appendMoveTo(double x, double y);
   void appendLineTo(double x, double y);
   void appendCubicBezierTo(double x1, double y1, double x2, double y2, double x, double y);
@@ -69,6 +50,7 @@ public:
   void appendPath(const CDRPath &path);
 
   void writeOut(WPXPropertyListVector &vec) const;
+  void writeOut(WPXString &path, WPXString &viewBox, double &width) const;
   void transform(const CDRTransforms &trafos);
   void transform(const CDRTransform &trafo);
   CDRPathElement *clone();
@@ -77,9 +59,6 @@ public:
   bool empty() const;
   bool isClosed() const;
 
-private:
-  CDRPath &operator=(const CDRPath &path);
-
 private:
   std::vector<CDRPathElement *> m_elements;
   bool m_isClosed;
