@@ -1,30 +1,10 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libcdr
- * Version: MPL 1.1 / GPLv2+ / LGPLv2+
+/*
+ * This file is part of the libcdr project.
  *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License or as specified alternatively below. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * Major Contributor(s):
- * Copyright (C) 2011 Fridrich Strba <fridrich.strba@bluewin.ch>
- *
- *
- * All Rights Reserved.
- *
- * For minor contributions see the git repository.
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
- * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
- * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
- * instead of those above.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #include <libwpd-stream/libwpd-stream.h>
@@ -99,7 +79,7 @@ bool libcdr::CMXParser::parseRecord(WPXInputStream *input, unsigned level)
 
     CDR_DEBUG_MSG(("Record: level %u %s, length: 0x%.8x (%u)\n", level, toFourCC(fourCC), length, length));
 
-    if (fourCC == FOURCC_RIFF || fourCC == FOURCC_RIFX || fourCC == FOURCC_LIST)
+    if (fourCC == CDR_FOURCC_RIFF || fourCC == CDR_FOURCC_RIFX || fourCC == CDR_FOURCC_LIST)
     {
 #ifdef DEBUG
       unsigned listType = readU32(input);
@@ -129,16 +109,16 @@ void libcdr::CMXParser::readRecord(unsigned fourCC, unsigned &length, WPXInputSt
   long recordEnd = input->tell() + length;
   switch (fourCC)
   {
-  case FOURCC_cont:
+  case CDR_FOURCC_cont:
     readCMXHeader(input);
     break;
-  case FOURCC_DISP:
+  case CDR_FOURCC_DISP:
     readDisp(input, length);
     break;
-  case FOURCC_page:
+  case CDR_FOURCC_page:
     readPage(input, length);
     break;
-  case FOURCC_ccmm:
+  case CDR_FOURCC_ccmm:
     readCcmm(input, recordEnd);
     break;
   default:
@@ -479,6 +459,7 @@ void libcdr::CMXParser::readEllipse(WPXInputStream *input)
     return;
 
   m_collector->collectObject(1);
+  CDRPath path;
   if (angle1 != angle2)
   {
     if (angle2 < angle1)
@@ -491,13 +472,13 @@ void libcdr::CMXParser::readEllipse(WPXInputStream *input)
 
     bool largeArc = (angle2 - angle1 > M_PI || angle2 - angle1 < -M_PI);
 
-    m_collector->collectMoveTo(x0, y0);
-    m_collector->collectArcTo(rx, ry, largeArc, true, x1, y1);
+    path.appendMoveTo(x0, y0);
+    path.appendArcTo(rx, ry, 0.0, largeArc, true, x1, y1);
     if (pie)
     {
-      m_collector->collectLineTo(cx, cy);
-      m_collector->collectLineTo(x0, y0);
-      m_collector->collectClosePath();
+      path.appendLineTo(cx, cy);
+      path.appendLineTo(x0, y0);
+      path.appendClosePath();
     }
   }
   else
@@ -508,10 +489,11 @@ void libcdr::CMXParser::readEllipse(WPXInputStream *input)
     double x1 = cx;
     double y1 = cy - ry;
 
-    m_collector->collectMoveTo(x0, y0);
-    m_collector->collectArcTo(rx, ry, false, true, x1, y1);
-    m_collector->collectArcTo(rx, ry, true, true, x0, y0);
+    path.appendMoveTo(x0, y0);
+    path.appendArcTo(rx, ry, 0.0, false, true, x1, y1);
+    path.appendArcTo(rx, ry, 0.0, true, true, x0, y0);
   }
+  m_collector->collectPath(path);
   m_collector->collectRotate(rotation, cx, cy);
   m_collector->collectLevel(1);
 }
@@ -577,26 +559,28 @@ void libcdr::CMXParser::readRectangle(WPXInputStream *input)
   double y0 = cy - height / 2.0;
   double x1 = cx + width / 2.0;
   double y1 = cy + height / 2.0;
+  CDRPath path;
   if (radius > 0.0)
   {
-    m_collector->collectMoveTo(x0, y0-radius);
-    m_collector->collectLineTo(x0, y1+radius);
-    m_collector->collectQuadraticBezier(x0, y1, x0+radius, y1);
-    m_collector->collectLineTo(x1-radius, y1);
-    m_collector->collectQuadraticBezier(x1, y1, x1, y1+radius);
-    m_collector->collectLineTo(x1, y0-radius);
-    m_collector->collectQuadraticBezier(x1, y0, x1-radius, y0);
-    m_collector->collectLineTo(x0+radius, y0);
-    m_collector->collectQuadraticBezier(x0, y0, x0, y0-radius);
+    path.appendMoveTo(x0, y0-radius);
+    path.appendLineTo(x0, y1+radius);
+    path.appendQuadraticBezierTo(x0, y1, x0+radius, y1);
+    path.appendLineTo(x1-radius, y1);
+    path.appendQuadraticBezierTo(x1, y1, x1, y1+radius);
+    path.appendLineTo(x1, y0-radius);
+    path.appendQuadraticBezierTo(x1, y0, x1-radius, y0);
+    path.appendLineTo(x0+radius, y0);
+    path.appendQuadraticBezierTo(x0, y0, x0, y0-radius);
   }
   else
   {
-    m_collector->collectMoveTo(x0, y0);
-    m_collector->collectLineTo(x0, y1);
-    m_collector->collectLineTo(x1, y1);
-    m_collector->collectLineTo(x1, y0);
-    m_collector->collectLineTo(x0, y0);
+    path.appendMoveTo(x0, y0);
+    path.appendLineTo(x0, y1);
+    path.appendLineTo(x1, y1);
+    path.appendLineTo(x1, y0);
+    path.appendLineTo(x0, y0);
   }
+  m_collector->collectPath(path);
   m_collector->collectRotate(angle, cx, cy);
   m_collector->collectLevel(1);
 }
@@ -634,14 +618,14 @@ libcdr::CDRBox libcdr::CMXParser::readBBox(WPXInputStream *input)
 
 void libcdr::CMXParser::readFill(WPXInputStream *input)
 {
-  unsigned char tagId = 0;
-  unsigned short tagLength = 0;
   unsigned fillIdentifier = readU16(input, m_bigEndian);
   switch (fillIdentifier)
   {
   case 1:
     if (m_precision == libcdr::PRECISION_32BIT)
     {
+      unsigned char tagId = 0;
+      unsigned short tagLength = 0;
       do
       {
         long startOffset = input->tell();
